@@ -35,7 +35,7 @@ def getargcount(iteratee, maxargs):
     """Return argument count of iteratee function."""
     if hasattr(iteratee, "_argcount"):
         # Optimization feature where argcount of iteratee is known and properly
-        # set by initator.
+        # set by initiator.
         return iteratee._argcount
 
     if isinstance(iteratee, type) or pyd.is_builtin(iteratee):
@@ -102,7 +102,7 @@ def iteriteratee(obj, iteratee=None, reverse=False):
 
 def iterator(obj):
     """Return iterative based on object type."""
-    if isinstance(obj, dict):
+    if isinstance(obj, Mapping):
         return obj.items()
     elif hasattr(obj, "iteritems"):
         return obj.iteritems()  # noqa: B301
@@ -178,6 +178,7 @@ def _base_get_item(obj, key, default=UNSET):
 def _base_get_object(obj, key, default=UNSET):
     value = _base_get_item(obj, key, default=UNSET)
     if value is UNSET:
+        _raise_if_restricted_key(key)
         value = default
         try:
             value = getattr(obj, key)
@@ -186,6 +187,15 @@ def _base_get_object(obj, key, default=UNSET):
     return value
 
 
+def _raise_if_restricted_key(key):
+    if not isinstance(key, str):
+        return
+    # Prevent access to dunder-methods since this could expose access to globals through leaky
+    # attributes such as obj.__init__.__globals__.
+    if len(key) > 4 and key.isascii() and key.startswith("__") and key.endswith("__"):
+        raise KeyError(f"access to restricted key {key!r} is not allowed")
+
+
 def base_set(obj, key, value, allow_override=True):
     """
     Set an object's `key` to `value`. If `obj` is a ``list`` and the `key` is the next available
@@ -213,6 +223,7 @@ def base_set(obj, key, value, allow_override=True):
                 obj[:] = (obj + [None] * key)[:key]
             obj.append(value)
     elif (allow_override or not hasattr(obj, key)) and obj is not None:
+        _raise_if_restricted_key(key)
         setattr(obj, key, value)
 
     return obj
